@@ -1,6 +1,6 @@
 package App::venn ;  
-our $VERSION = '0.101' ; 
-our $DATE = '2021-06-06T13:33+09:00' ; 
+our $VERSION = '0.110' ; 
+our $DATE = '2021-06-08T17:47+09:00' ; 
 
 =encoding utf8
 
@@ -27,9 +27,9 @@ $ function y(){ echo -n $* | perl -pe's/./$&\n/g' } # ← Defined a shell functi
 $ venn <(y ABCCCC) <(y AABDEF) <(y ABBDEF) <(y DEEEF) # Each <(...) means the process substitution. Each is treated as a file as the result of the contained command. Out follows next 4 lines:
 
   cardi. file1  file2  file3  file4  strmin strmax
-  2.     2      3      3      0      "A"    "B"
-  1.     4      0      0      0      "C"
-  3.     0      3      3      5      "D"    "F"
+  2.     2      3      3      0      'A'    'B'
+  1.     4      0      0      0      'C'
+  3.     0      3      3      5      'D'    'F'
 
 　この例では、あたかも{A,B,C,C,C,C}と{A,A,B,D,E,F}と{A,B,B,D,E,F}と{D,E,E,E,F}に相当する4個のファイルがあって、
 それぞれは改行区切りで1文字ずつ格納されています。そのようなファイル群(以下、fiel1〜4とする)がvennに与えられています。
